# In-hospital Mortality Prediction

Like in-ICU mortality prediction, this can be used as a signal of a patient's overall level of wellness or a
proxy signal for the patient's need to be transferred to higher monitoring or care levels. It is often a good
idea to separate this from post-discharge mortality prediction due to the vastly different intervention
surfaces that could be applied in either an inpatient or outpatient setting as well as the differing likely
clinical causes of risk of mortality in those settings.
